@@ -226,6 +226,14 @@ class DocDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#close)
+        """
+
     def copy_db_cluster_parameter_group(
         self,
         *,
@@ -331,6 +339,7 @@ class DocDBClient(BaseClient):
         PreferredMaintenanceWindow: str = ...,
         AutoMinorVersionUpgrade: bool = ...,
         Tags: Sequence[TagTypeDef] = ...,
+        CopyTagsToSnapshot: bool = ...,
         PromotionTier: int = ...,
         EnablePerformanceInsights: bool = ...,
         PerformanceInsightsKMSKeyId: str = ...
@@ -813,6 +822,7 @@ class DocDBClient(BaseClient):
         AutoMinorVersionUpgrade: bool = ...,
         NewDBInstanceIdentifier: str = ...,
         CACertificateIdentifier: str = ...,
+        CopyTagsToSnapshot: bool = ...,
         PromotionTier: int = ...,
         EnablePerformanceInsights: bool = ...,
         PerformanceInsightsKMSKeyId: str = ...
@@ -951,6 +961,7 @@ class DocDBClient(BaseClient):
         *,
         DBClusterIdentifier: str,
         SourceDBClusterIdentifier: str,
+        RestoreType: str = ...,
         RestoreToTime: Union[datetime, str] = ...,
         UseLatestRestorableTime: bool = ...,
         Port: int = ...,
