@@ -46,8 +46,7 @@ Usage::
 from datetime import datetime
 from typing import Generic, Iterator, Sequence, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import SourceTypeType
 from .type_defs import (
@@ -95,7 +94,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeCertificatesPaginator(Boto3Paginator):
+class DescribeCertificatesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeCertificates)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describecertificatespaginator)
@@ -114,7 +113,7 @@ class DescribeCertificatesPaginator(Boto3Paginator):
         """
 
 
-class DescribeDBClusterParameterGroupsPaginator(Boto3Paginator):
+class DescribeDBClusterParameterGroupsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameterGroups)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describedbclusterparametergroupspaginator)
@@ -133,7 +132,7 @@ class DescribeDBClusterParameterGroupsPaginator(Boto3Paginator):
         """
 
 
-class DescribeDBClusterParametersPaginator(Boto3Paginator):
+class DescribeDBClusterParametersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameters)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describedbclusterparameterspaginator)
@@ -153,7 +152,7 @@ class DescribeDBClusterParametersPaginator(Boto3Paginator):
         """
 
 
-class DescribeDBClusterSnapshotsPaginator(Boto3Paginator):
+class DescribeDBClusterSnapshotsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterSnapshots)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describedbclustersnapshotspaginator)
@@ -176,7 +175,7 @@ class DescribeDBClusterSnapshotsPaginator(Boto3Paginator):
         """
 
 
-class DescribeDBClustersPaginator(Boto3Paginator):
+class DescribeDBClustersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describedbclusterspaginator)
@@ -195,7 +194,7 @@ class DescribeDBClustersPaginator(Boto3Paginator):
         """
 
 
-class DescribeDBEngineVersionsPaginator(Boto3Paginator):
+class DescribeDBEngineVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describedbengineversionspaginator)
@@ -219,7 +218,7 @@ class DescribeDBEngineVersionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeDBInstancesPaginator(Boto3Paginator):
+class DescribeDBInstancesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describedbinstancespaginator)
@@ -238,7 +237,7 @@ class DescribeDBInstancesPaginator(Boto3Paginator):
         """
 
 
-class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
+class DescribeDBSubnetGroupsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describedbsubnetgroupspaginator)
@@ -257,7 +256,7 @@ class DescribeDBSubnetGroupsPaginator(Boto3Paginator):
         """
 
 
-class DescribeEventSubscriptionsPaginator(Boto3Paginator):
+class DescribeEventSubscriptionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeEventSubscriptions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describeeventsubscriptionspaginator)
@@ -276,7 +275,7 @@ class DescribeEventSubscriptionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeEventsPaginator(Boto3Paginator):
+class DescribeEventsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describeeventspaginator)
@@ -300,7 +299,7 @@ class DescribeEventsPaginator(Boto3Paginator):
         """
 
 
-class DescribeGlobalClustersPaginator(Boto3Paginator):
+class DescribeGlobalClustersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeGlobalClusters)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describeglobalclusterspaginator)
@@ -319,7 +318,7 @@ class DescribeGlobalClustersPaginator(Boto3Paginator):
         """
 
 
-class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
+class DescribeOrderableDBInstanceOptionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describeorderabledbinstanceoptionspaginator)
@@ -342,7 +341,7 @@ class DescribeOrderableDBInstanceOptionsPaginator(Boto3Paginator):
         """
 
 
-class DescribePendingMaintenanceActionsPaginator(Boto3Paginator):
+class DescribePendingMaintenanceActionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Paginator.DescribePendingMaintenanceActions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/paginators/#describependingmaintenanceactionspaginator)
