@@ -590,6 +590,7 @@ _OptionalModifyDBInstanceMessageRequestTypeDef = TypedDict(
         "AutoMinorVersionUpgrade": bool,
         "NewDBInstanceIdentifier": str,
         "CACertificateIdentifier": str,
+        "CopyTagsToSnapshot": bool,
         "PromotionTier": int,
         "EnablePerformanceInsights": bool,
         "PerformanceInsightsKMSKeyId": str,
@@ -982,6 +983,7 @@ _OptionalCreateDBInstanceMessageRequestTypeDef = TypedDict(
         "PreferredMaintenanceWindow": str,
         "AutoMinorVersionUpgrade": bool,
         "Tags": Sequence[TagTypeDef],
+        "CopyTagsToSnapshot": bool,
         "PromotionTier": int,
         "EnablePerformanceInsights": bool,
         "PerformanceInsightsKMSKeyId": str,
@@ -1089,6 +1091,7 @@ _RequiredRestoreDBClusterToPointInTimeMessageRequestTypeDef = TypedDict(
 _OptionalRestoreDBClusterToPointInTimeMessageRequestTypeDef = TypedDict(
     "_OptionalRestoreDBClusterToPointInTimeMessageRequestTypeDef",
     {
+        "RestoreType": str,
         "RestoreToTime": Union[datetime, str],
         "UseLatestRestorableTime": bool,
         "Port": int,
@@ -1330,6 +1333,7 @@ DBClusterTypeDef = TypedDict(
         "DbClusterResourceId": str,
         "DBClusterArn": str,
         "AssociatedRoles": List[DBClusterRoleTypeDef],
+        "CloneGroupId": str,
         "ClusterCreateTime": datetime,
         "EnabledCloudwatchLogsExports": List[str],
         "DeletionProtection": bool,
@@ -2080,6 +2084,7 @@ DBInstanceTypeDef = TypedDict(
         "KmsKeyId": str,
         "DbiResourceId": str,
         "CACertificateIdentifier": str,
+        "CopyTagsToSnapshot": bool,
         "PromotionTier": int,
         "DBInstanceArn": str,
         "EnabledCloudwatchLogsExports": List[str],
