@@ -23,14 +23,14 @@ Usage::
 """
 from typing import Sequence
 
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import FilterTypeDef, WaiterConfigTypeDef
 
 __all__ = ("DBInstanceAvailableWaiter", "DBInstanceDeletedWaiter")
 
 
-class DBInstanceAvailableWaiter(Boto3Waiter):
+class DBInstanceAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Waiter.DBInstanceAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters/#dbinstanceavailablewaiter)
@@ -51,7 +51,7 @@ class DBInstanceAvailableWaiter(Boto3Waiter):
         """
 
 
-class DBInstanceDeletedWaiter(Boto3Waiter):
+class DBInstanceDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Waiter.DBInstanceDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/waiters/#dbinstancedeletedwaiter)
